beamprofiler.iso.characterizing\_parameters.fractional\_power
=============================================================

.. currentmodule:: beamprofiler.iso.characterizing_parameters

.. autofunction:: fractional_power